@@ -20,7 +20,7 @@ except ImportError:
 from bitmaptools import draw_line
 from vectorio import Rectangle
 
-__version__ = "0.9.0"
+__version__ = "0.9.1"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 # pylint: disable=too-many-arguments, invalid-name, protected-access
@@ -38,7 +38,7 @@ class ubar:
         :param list x: x data
         :param list y: y data
         :param int color: boxes color. Defaults to const:``0xFFFFFF``
-        :param bool fill: boxes fill attrribute. Defaults to `False`
+        :param bool fill: boxes fill attribute. Defaults to `False`
 
         """
 
