@@ -22,7 +22,7 @@ from bitmaptools import draw_line, fill_region
 from ulab import numpy as np
 from vectorio import Polygon
 
-__version__ = "0.9.0"
+__version__ = "0.9.1"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 
@@ -38,9 +38,9 @@ class ucartesian:
         plot: Uplot,
         x: Union[list, np.linspace, np.ndarray],
         y: Union[list, np.linspace, np.ndarray],
-        rangex: Optional[Union[list, None]] = None,
-        rangey: Optional[Union[list, None]] = None,
-        line_color: Optional[Union[int, None]] = None,
+        rangex: Optional[list] = None,
+        rangey: Optional[list] = None,
+        line_color: Optional[int] = None,
         fill: bool = False,
         nudge: bool = True,
         logging: bool = False,
