@@ -22,7 +22,7 @@ except ImportError:
 import math
 from vectorio import Polygon
 
-__version__ = "0.9.0"
+__version__ = "0.9.1"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 # pylint: disable=too-many-arguments, invalid-name, no-self-use
@@ -73,12 +73,10 @@ class upie:
     def get_points(self, x: int, y: int, radius: int, angle: float) -> None:
         """
 
-        :param bitmap: bitmap to be drawn in
         :param x: center x coordinate
         :param y: center y coordinate
         :param radius: pie radius in pixels
         :param angle: line angle
-        :param color: color index
         :return: None
 
         """
