@@ -26,7 +26,6 @@ try:
     from typing_extensions import Literal
 except ImportError:
     pass
-
 import displayio
 import terminalio
 from bitmaptools import draw_line
@@ -34,7 +33,7 @@ from vectorio import Circle
 from ulab import numpy as np
 
 
-__version__ = "0.9.0"
+__version__ = "0.9.1"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 
@@ -74,7 +73,7 @@ class Uplot(displayio.Group):
         box_color: int = 0xFFFFFF,
         tickx_height: int = 8,
         ticky_height: int = 8,
-        scale: int = 1
+        scale: int = 1,
     ) -> None:
         if width not in range(50, 481) and scale == 1:
             print("Be sure to verify your values. Defaulting to width=100")
