@@ -25,7 +25,7 @@ from ulab import numpy as np
 import displayio
 from vectorio import Circle
 
-__version__ = "0.9.0"
+__version__ = "0.9.1"
 __repo__ = "https://github.com/adafruit/CircuitPython_uplot.git"
 
 
@@ -40,8 +40,8 @@ class uscatter:
         plot: Uplot,
         x: Union[list, np.linspace, np.ndarray],
         y: Union[list, np.linspace, np.ndarray],
-        rangex: Optional[Union[list, None]] = None,
-        rangey: Optional[Union[list, None]] = None,
+        rangex: Optional[list] = None,
+        rangey: Optional[list] = None,
         radius: Optional[Union[list, int]] = 3,
         circle_color: int = 0xFF905D,
         nudge: bool = True,
