@@ -3,6 +3,7 @@
 # SPDX-License-Identifier: MIT
 
 import time
+from random import choice
 import board
 from ulab import numpy as np
 from circuitpython_uplot.uplot import Uplot
@@ -16,21 +17,13 @@ display = board.DISPLAY
 plot = Uplot(0, 0, display.width, display.height, show_box=False)
 
 # Setting some date to plot
-x = np.array(
-    [
-        [1, 3, 9, 25],
-        [12, 8, 4, 2],
-        [18, 3, 7, 5],
-        [2, 10, 9, 22],
-        [8, 8, 14, 12],
-        [3, 13, 17, 15],
-    ],
-    dtype=np.int16,
-)
+x = np.linspace(-4, 4, num=100)
+y = 2.0 / np.sqrt(2 * np.pi) * np.exp((-(x**2)) / 4.0)
+b = [choice(y) for _ in y]
+y1 = np.array(b).reshape((10, 10))
 
 # Plotting and showing the plot
-umap(plot, x, 0xFF0000, 0x0000FF)
-
+umap(plot, y1, 0xFF0044, 0x4400FF)
 # Plotting and showing the plot
 display.show(plot)
 
